# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ModifyAppPolicyRequest(DaraModel):
    def __init__(
        self,
        app_policy_id: str = None,
        product_type: str = None,
        video_policy: main_models.ModifyAppPolicyRequestVideoPolicy = None,
    ):
        # The policy ID.
        # 
        # This parameter is required.
        self.app_policy_id = app_policy_id
        # The product type.
        # 
        # Enumerated values:
        # 
        # *   CloudApp: RDS Cloud App
        # 
        # This parameter is required.
        self.product_type = product_type
        # Displays the policy.
        self.video_policy = video_policy

    def validate(self):
        if self.video_policy:
            self.video_policy.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_policy_id is not None:
            result['AppPolicyId'] = self.app_policy_id

        if self.product_type is not None:
            result['ProductType'] = self.product_type

        if self.video_policy is not None:
            result['VideoPolicy'] = self.video_policy.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppPolicyId') is not None:
            self.app_policy_id = m.get('AppPolicyId')

        if m.get('ProductType') is not None:
            self.product_type = m.get('ProductType')

        if m.get('VideoPolicy') is not None:
            temp_model = main_models.ModifyAppPolicyRequestVideoPolicy()
            self.video_policy = temp_model.from_map(m.get('VideoPolicy'))

        return self

class ModifyAppPolicyRequestVideoPolicy(DaraModel):
    def __init__(
        self,
        frame_rate: int = None,
        session_resolution_height: int = None,
        session_resolution_width: int = None,
        streaming_mode: str = None,
        terminal_resolution_adaptive: bool = None,
        visual_quality_strategy: str = None,
        webrtc: bool = None,
    ):
        # The frame rate (FPS).
        # 
        # Enumerated values:
        # 
        # *   30: 30 FPS
        # *   60: 60 FPS
        self.frame_rate = frame_rate
        # The height of the resolution, in pixels.
        self.session_resolution_height = session_resolution_height
        # The width of the resolution, in pixels.
        self.session_resolution_width = session_resolution_width
        # The stream mode. This parameter is used together with `Webrtc` to specify the protocol type.
        # 
        # *   If you set `Webrtc` to `true` and `StreamingMode` to `video`, Web Real-Time Communications (WebRTC) streams are used.
        # *   If you set `Webrtc` to `false` and `StreamingMode` to `video`, video streams are used.
        # *   If you set `Webrtc` to `false` and `StreamingMode` to `mix`, mixed streams are used.
        self.streaming_mode = streaming_mode
        # Whether to use adaptive resolution.
        # 
        # *   `true`: The session resolution changes with the display area of the terminal. In this case, `SessionResolutionWidth` indicates the maximum resolution width and `SessionResolutionHeight` indicates the maximum resolution height.
        # *   `false`: The session resolution does not change with the display area of the terminal. In this case, `SessionResolutionWidth` specifies the fixed resolution width and `SessionResolutionHeight` specifies the fixed resolution height.
        self.terminal_resolution_adaptive = terminal_resolution_adaptive
        # The image quality policy.
        # 
        # Enumerated values:
        # 
        # *   adaptive: adaptive.
        # *   smooth: smooth first.
        # *   quality: quality first.
        self.visual_quality_strategy = visual_quality_strategy
        # Specifies whether to enable WebRTC. This parameter is used together with `StreamingMode` to specify the protocol type.
        # 
        # *   If you set `Webrtc` to `true` and `StreamingMode` to `video`, WebRTC streams are used.
        # *   If you set `Webrtc` to `false` and `StreamingMode` to `video`, video streams are used.
        # *   If you set `Webrtc` to `false` and `StreamingMode` to `mix`, mixed streams are used.
        self.webrtc = webrtc

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.frame_rate is not None:
            result['FrameRate'] = self.frame_rate

        if self.session_resolution_height is not None:
            result['SessionResolutionHeight'] = self.session_resolution_height

        if self.session_resolution_width is not None:
            result['SessionResolutionWidth'] = self.session_resolution_width

        if self.streaming_mode is not None:
            result['StreamingMode'] = self.streaming_mode

        if self.terminal_resolution_adaptive is not None:
            result['TerminalResolutionAdaptive'] = self.terminal_resolution_adaptive

        if self.visual_quality_strategy is not None:
            result['VisualQualityStrategy'] = self.visual_quality_strategy

        if self.webrtc is not None:
            result['Webrtc'] = self.webrtc

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FrameRate') is not None:
            self.frame_rate = m.get('FrameRate')

        if m.get('SessionResolutionHeight') is not None:
            self.session_resolution_height = m.get('SessionResolutionHeight')

        if m.get('SessionResolutionWidth') is not None:
            self.session_resolution_width = m.get('SessionResolutionWidth')

        if m.get('StreamingMode') is not None:
            self.streaming_mode = m.get('StreamingMode')

        if m.get('TerminalResolutionAdaptive') is not None:
            self.terminal_resolution_adaptive = m.get('TerminalResolutionAdaptive')

        if m.get('VisualQualityStrategy') is not None:
            self.visual_quality_strategy = m.get('VisualQualityStrategy')

        if m.get('Webrtc') is not None:
            self.webrtc = m.get('Webrtc')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListTenantConfigResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        tenant_config_model: main_models.ListTenantConfigResponseBodyTenantConfigModel = None,
    ):
        # The request ID.
        self.request_id = request_id
        # The user configurations.
        self.tenant_config_model = tenant_config_model

    def validate(self):
        if self.tenant_config_model:
            self.tenant_config_model.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.tenant_config_model is not None:
            result['TenantConfigModel'] = self.tenant_config_model.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TenantConfigModel') is not None:
            temp_model = main_models.ListTenantConfigResponseBodyTenantConfigModel()
            self.tenant_config_model = temp_model.from_map(m.get('TenantConfigModel'))

        return self

class ListTenantConfigResponseBodyTenantConfigModel(DaraModel):
    def __init__(
        self,
        app_instance_group_expire_remind: bool = None,
    ):
        # Indicates whether the resource expiration reminder feature is enabled.
        # 
        # Valid values:
        # 
        # *   true
        # *   false
        self.app_instance_group_expire_remind = app_instance_group_expire_remind

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_expire_remind is not None:
            result['AppInstanceGroupExpireRemind'] = self.app_instance_group_expire_remind

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupExpireRemind') is not None:
            self.app_instance_group_expire_remind = m.get('AppInstanceGroupExpireRemind')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class ListWuyingServerRequest(DaraModel):
    def __init__(
        self,
        add_virtual_node_pool_status_list: List[str] = None,
        biz_region_id: str = None,
        charge_type: str = None,
        image_id: str = None,
        office_site_id: str = None,
        page_number: int = None,
        page_size: int = None,
        server_instance_type: str = None,
        status: str = None,
        virtual_node_pool_id: str = None,
        wuying_server_id_list: List[str] = None,
        wuying_server_name_or_id: str = None,
    ):
        self.add_virtual_node_pool_status_list = add_virtual_node_pool_status_list
        # The region ID.
        self.biz_region_id = biz_region_id
        # The billing method of the Internet access package.
        self.charge_type = charge_type
        # The image ID.
        self.image_id = image_id
        # The office network IDs.
        self.office_site_id = office_site_id
        # The page number.
        self.page_number = page_number
        # The number of records per page.
        self.page_size = page_size
        # Workstation specifications.
        self.server_instance_type = server_instance_type
        # The status of the workstation.
        self.status = status
        self.virtual_node_pool_id = virtual_node_pool_id
        # The list of workstation IDs.
        self.wuying_server_id_list = wuying_server_id_list
        # The workstation name or workstation ID.
        self.wuying_server_name_or_id = wuying_server_name_or_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.add_virtual_node_pool_status_list is not None:
            result['AddVirtualNodePoolStatusList'] = self.add_virtual_node_pool_status_list

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        if self.server_instance_type is not None:
            result['ServerInstanceType'] = self.server_instance_type

        if self.status is not None:
            result['Status'] = self.status

        if self.virtual_node_pool_id is not None:
            result['VirtualNodePoolId'] = self.virtual_node_pool_id

        if self.wuying_server_id_list is not None:
            result['WuyingServerIdList'] = self.wuying_server_id_list

        if self.wuying_server_name_or_id is not None:
            result['WuyingServerNameOrId'] = self.wuying_server_name_or_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AddVirtualNodePoolStatusList') is not None:
            self.add_virtual_node_pool_status_list = m.get('AddVirtualNodePoolStatusList')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        if m.get('ServerInstanceType') is not None:
            self.server_instance_type = m.get('ServerInstanceType')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('VirtualNodePoolId') is not None:
            self.virtual_node_pool_id = m.get('VirtualNodePoolId')

        if m.get('WuyingServerIdList') is not None:
            self.wuying_server_id_list = m.get('WuyingServerIdList')

        if m.get('WuyingServerNameOrId') is not None:
            self.wuying_server_name_or_id = m.get('WuyingServerNameOrId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class CreateWuyingServerRequest(DaraModel):
    def __init__(
        self,
        amount: int = None,
        auto_pay: bool = None,
        auto_renew: bool = None,
        bandwidth: int = None,
        biz_region_id: str = None,
        charge_type: str = None,
        data_disk: List[main_models.CreateWuyingServerRequestDataDisk] = None,
        host_name: str = None,
        idempotence_token: str = None,
        image_id: str = None,
        max_price: float = None,
        network_strategy_type: str = None,
        office_site_id: str = None,
        password: str = None,
        period: int = None,
        period_unit: str = None,
        promotion_id: str = None,
        saving_plan_id: str = None,
        server_instance_type: str = None,
        server_port_range: str = None,
        sub_pay_type: str = None,
        system_disk_category: str = None,
        system_disk_performance_level: str = None,
        system_disk_size: int = None,
        v_switch_ids: List[str] = None,
        virtual_node_pool_id: str = None,
        wuying_server_name: str = None,
    ):
        # Quantity.
        self.amount = amount
        # Auto payment.
        self.auto_pay = auto_pay
        # Auto-renewal.
        self.auto_renew = auto_renew
        # bandwidth value, the NetworkStrategyType is valid for DirectIp. Unit: Mbps, range 2~100
        self.bandwidth = bandwidth
        # Region.
        self.biz_region_id = biz_region_id
        # The billing method.
        # 
        # Valid values:
        # 
        # *   PrePaid: subscription
        self.charge_type = charge_type
        # The list of data disks.
        self.data_disk = data_disk
        self.host_name = host_name
        # Idempotence token to ensure operation uniqueness
        self.idempotence_token = idempotence_token
        # The ID of the image.
        self.image_id = image_id
        self.max_price = max_price
        # The type of the network policy (in invitational preview).
        self.network_strategy_type = network_strategy_type
        # The office network IDs.
        self.office_site_id = office_site_id
        # Workstation login password.
        self.password = password
        # The subscription period.
        self.period = period
        # The time unit.
        # 
        # Valid values:
        # 
        # *   Month
        # *   Year
        self.period_unit = period_unit
        # The ID of the discount.
        # 
        # >  If PromotionId is set, it will try to apply the corresponding discount.
        self.promotion_id = promotion_id
        self.saving_plan_id = saving_plan_id
        # Workstation specifications.
        self.server_instance_type = server_instance_type
        self.server_port_range = server_port_range
        self.sub_pay_type = sub_pay_type
        # The system disk category.
        # 
        # Valid values:
        # 
        # *   cloud_auto.
        self.system_disk_category = system_disk_category
        # The performance level (PL) of the system disk.
        self.system_disk_performance_level = system_disk_performance_level
        # The size of the system disk. Unit: GB.
        self.system_disk_size = system_disk_size
        # The list of office network vSwitches.
        self.v_switch_ids = v_switch_ids
        self.virtual_node_pool_id = virtual_node_pool_id
        # The name of the workstation. The numeric suffix is automatically added when multiple workstations are created.
        self.wuying_server_name = wuying_server_name

    def validate(self):
        if self.data_disk:
            for v1 in self.data_disk:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.amount is not None:
            result['Amount'] = self.amount

        if self.auto_pay is not None:
            result['AutoPay'] = self.auto_pay

        if self.auto_renew is not None:
            result['AutoRenew'] = self.auto_renew

        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth

        if self.biz_region_id is not None:
            result['BizRegionId'] = self.biz_region_id

        if self.charge_type is not None:
            result['ChargeType'] = self.charge_type

        result['DataDisk'] = []
        if self.data_disk is not None:
            for k1 in self.data_disk:
                result['DataDisk'].append(k1.to_map() if k1 else None)

        if self.host_name is not None:
            result['HostName'] = self.host_name

        if self.idempotence_token is not None:
            result['IdempotenceToken'] = self.idempotence_token

        if self.image_id is not None:
            result['ImageId'] = self.image_id

        if self.max_price is not None:
            result['MaxPrice'] = self.max_price

        if self.network_strategy_type is not None:
            result['NetworkStrategyType'] = self.network_strategy_type

        if self.office_site_id is not None:
            result['OfficeSiteId'] = self.office_site_id

        if self.password is not None:
            result['Password'] = self.password

        if self.period is not None:
            result['Period'] = self.period

        if self.period_unit is not None:
            result['PeriodUnit'] = self.period_unit

        if self.promotion_id is not None:
            result['PromotionId'] = self.promotion_id

        if self.saving_plan_id is not None:
            result['SavingPlanId'] = self.saving_plan_id

        if self.server_instance_type is not None:
            result['ServerInstanceType'] = self.server_instance_type

        if self.server_port_range is not None:
            result['ServerPortRange'] = self.server_port_range

        if self.sub_pay_type is not None:
            result['SubPayType'] = self.sub_pay_type

        if self.system_disk_category is not None:
            result['SystemDiskCategory'] = self.system_disk_category

        if self.system_disk_performance_level is not None:
            result['SystemDiskPerformanceLevel'] = self.system_disk_performance_level

        if self.system_disk_size is not None:
            result['SystemDiskSize'] = self.system_disk_size

        if self.v_switch_ids is not None:
            result['VSwitchIds'] = self.v_switch_ids

        if self.virtual_node_pool_id is not None:
            result['VirtualNodePoolId'] = self.virtual_node_pool_id

        if self.wuying_server_name is not None:
            result['WuyingServerName'] = self.wuying_server_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Amount') is not None:
            self.amount = m.get('Amount')

        if m.get('AutoPay') is not None:
            self.auto_pay = m.get('AutoPay')

        if m.get('AutoRenew') is not None:
            self.auto_renew = m.get('AutoRenew')

        if m.get('Bandwidth') is not None:
            self.bandwidth = m.get('Bandwidth')

        if m.get('BizRegionId') is not None:
            self.biz_region_id = m.get('BizRegionId')

        if m.get('ChargeType') is not None:
            self.charge_type = m.get('ChargeType')

        self.data_disk = []
        if m.get('DataDisk') is not None:
            for k1 in m.get('DataDisk'):
                temp_model = main_models.CreateWuyingServerRequestDataDisk()
                self.data_disk.append(temp_model.from_map(k1))

        if m.get('HostName') is not None:
            self.host_name = m.get('HostName')

        if m.get('IdempotenceToken') is not None:
            self.idempotence_token = m.get('IdempotenceToken')

        if m.get('ImageId') is not None:
            self.image_id = m.get('ImageId')

        if m.get('MaxPrice') is not None:
            self.max_price = m.get('MaxPrice')

        if m.get('NetworkStrategyType') is not None:
            self.network_strategy_type = m.get('NetworkStrategyType')

        if m.get('OfficeSiteId') is not None:
            self.office_site_id = m.get('OfficeSiteId')

        if m.get('Password') is not None:
            self.password = m.get('Password')

        if m.get('Period') is not None:
            self.period = m.get('Period')

        if m.get('PeriodUnit') is not None:
            self.period_unit = m.get('PeriodUnit')

        if m.get('PromotionId') is not None:
            self.promotion_id = m.get('PromotionId')

        if m.get('SavingPlanId') is not None:
            self.saving_plan_id = m.get('SavingPlanId')

        if m.get('ServerInstanceType') is not None:
            self.server_instance_type = m.get('ServerInstanceType')

        if m.get('ServerPortRange') is not None:
            self.server_port_range = m.get('ServerPortRange')

        if m.get('SubPayType') is not None:
            self.sub_pay_type = m.get('SubPayType')

        if m.get('SystemDiskCategory') is not None:
            self.system_disk_category = m.get('SystemDiskCategory')

        if m.get('SystemDiskPerformanceLevel') is not None:
            self.system_disk_performance_level = m.get('SystemDiskPerformanceLevel')

        if m.get('SystemDiskSize') is not None:
            self.system_disk_size = m.get('SystemDiskSize')

        if m.get('VSwitchIds') is not None:
            self.v_switch_ids = m.get('VSwitchIds')

        if m.get('VirtualNodePoolId') is not None:
            self.virtual_node_pool_id = m.get('VirtualNodePoolId')

        if m.get('WuyingServerName') is not None:
            self.wuying_server_name = m.get('WuyingServerName')

        return self

class CreateWuyingServerRequestDataDisk(DaraModel):
    def __init__(
        self,
        data_disk_category: str = None,
        data_disk_performance_level: str = None,
        data_disk_size: int = None,
    ):
        # The data disk category.
        # 
        # Valid values:
        # 
        # *   cloud_auto.
        self.data_disk_category = data_disk_category
        # The PL of the data disk.
        self.data_disk_performance_level = data_disk_performance_level
        # The data disk size.
        self.data_disk_size = data_disk_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data_disk_category is not None:
            result['DataDiskCategory'] = self.data_disk_category

        if self.data_disk_performance_level is not None:
            result['DataDiskPerformanceLevel'] = self.data_disk_performance_level

        if self.data_disk_size is not None:
            result['DataDiskSize'] = self.data_disk_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataDiskCategory') is not None:
            self.data_disk_category = m.get('DataDiskCategory')

        if m.get('DataDiskPerformanceLevel') is not None:
            self.data_disk_performance_level = m.get('DataDiskPerformanceLevel')

        if m.get('DataDiskSize') is not None:
            self.data_disk_size = m.get('DataDiskSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_appstream_center20210901 import models as main_models
from darabonba.model import DaraModel

class ListPersistentAppInstancesResponseBody(DaraModel):
    def __init__(
        self,
        page_number: int = None,
        page_size: int = None,
        persistent_app_instance_models: List[main_models.ListPersistentAppInstancesResponseBodyPersistentAppInstanceModels] = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # The page number.
        self.page_number = page_number
        # The number of entries per page.
        self.page_size = page_size
        # The app instances of the persistent session type.
        self.persistent_app_instance_models = persistent_app_instance_models
        # The request ID.
        self.request_id = request_id
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.persistent_app_instance_models:
            for v1 in self.persistent_app_instance_models:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.page_number is not None:
            result['PageNumber'] = self.page_number

        if self.page_size is not None:
            result['PageSize'] = self.page_size

        result['PersistentAppInstanceModels'] = []
        if self.persistent_app_instance_models is not None:
            for k1 in self.persistent_app_instance_models:
                result['PersistentAppInstanceModels'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('PageNumber') is not None:
            self.page_number = m.get('PageNumber')

        if m.get('PageSize') is not None:
            self.page_size = m.get('PageSize')

        self.persistent_app_instance_models = []
        if m.get('PersistentAppInstanceModels') is not None:
            for k1 in m.get('PersistentAppInstanceModels'):
                temp_model = main_models.ListPersistentAppInstancesResponseBodyPersistentAppInstanceModels()
                self.persistent_app_instance_models.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListPersistentAppInstancesResponseBodyPersistentAppInstanceModels(DaraModel):
    def __init__(
        self,
        app_instance_group_id: str = None,
        app_instance_id: str = None,
        app_instance_persistent_id: str = None,
        app_instance_persistent_name: str = None,
        app_instance_persistent_status: str = None,
        app_instance_status: str = None,
        authorized_users: List[str] = None,
        gmt_create: str = None,
    ):
        # The ID of the delivery group.
        self.app_instance_group_id = app_instance_group_id
        # The ID of the app instance.
        self.app_instance_id = app_instance_id
        # The ID of the app instance of the persistent session type.
        self.app_instance_persistent_id = app_instance_persistent_id
        # The name of the app instance of the persistent session type.
        self.app_instance_persistent_name = app_instance_persistent_name
        # The status of the app instance of the persistent session type.
        # 
        # Valid values:
        # 
        # *   STARTING
        # *   RUNNING
        # *   STOPPED
        # *   UNAVAILABLE
        # *   DELETING
        # *   PENDING
        # *   STOPPING
        # *   DELETED
        # *   REBUILDING
        self.app_instance_persistent_status = app_instance_persistent_status
        # The status of the app instance.
        # 
        # Valid values:
        # 
        # *   INIT: The app instance is being initialized.
        # *   STARTING: The app instance is being started.
        # *   CLOSING: The app instance is being stopped.
        # *   CLOSED: The app instance is closed.
        # *   RUNNING: The app instance is running.
        # *   idle: The app instance is idle.
        # *   BOUND: The app instance is bound to an app instance group.
        # *   UNAVAILABLE: The app instance is unavailable.
        # *   DELETED: The app instance is deleted.
        self.app_instance_status = app_instance_status
        # The authorized users.
        self.authorized_users = authorized_users
        # The time when the app instance was created.
        self.gmt_create = gmt_create

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_instance_group_id is not None:
            result['AppInstanceGroupId'] = self.app_instance_group_id

        if self.app_instance_id is not None:
            result['AppInstanceId'] = self.app_instance_id

        if self.app_instance_persistent_id is not None:
            result['AppInstancePersistentId'] = self.app_instance_persistent_id

        if self.app_instance_persistent_name is not None:
            result['AppInstancePersistentName'] = self.app_instance_persistent_name

        if self.app_instance_persistent_status is not None:
            result['AppInstancePersistentStatus'] = self.app_instance_persistent_status

        if self.app_instance_status is not None:
            result['AppInstanceStatus'] = self.app_instance_status

        if self.authorized_users is not None:
            result['AuthorizedUsers'] = self.authorized_users

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppInstanceGroupId') is not None:
            self.app_instance_group_id = m.get('AppInstanceGroupId')

        if m.get('AppInstanceId') is not None:
            self.app_instance_id = m.get('AppInstanceId')

        if m.get('AppInstancePersistentId') is not None:
            self.app_instance_persistent_id = m.get('AppInstancePersistentId')

        if m.get('AppInstancePersistentName') is not None:
            self.app_instance_persistent_name = m.get('AppInstancePersistentName')

        if m.get('AppInstancePersistentStatus') is not None:
            self.app_instance_persistent_status = m.get('AppInstancePersistentStatus')

        if m.get('AppInstanceStatus') is not None:
            self.app_instance_status = m.get('AppInstanceStatus')

        if m.get('AuthorizedUsers') is not None:
            self.authorized_users = m.get('AuthorizedUsers')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        return self

